Learn R Programming

BayesXsrc (version 2.1-1)

run.bayesx: Run BayesX

Description

Run BayesX program files from R.

Usage

run.bayesx(prg = NULL, verbose = TRUE, ...)

Arguments

prg
a file path to a BayesX program file. If set to NULL, BayesX will start in batch mode.
verbose
should output be printed to the Rconsole during runtime of BayesX.
...
further arguments to be passed to system.

Value

  • If a prg file is provided, the function returns a list containg information if BayesX was succesfully launched and how long the process was running.

Details

Function uses system to run BayesX within an Rsession.

Examples

Run this code
## create a temporary directory for this example
dir <- tempdir()
prg <- file.path(dir, "demo.prg")

## generate some data
set.seed(111)
n <- 200

## regressor
dat <- data.frame(x = runif(n, -3, 3))

## response
dat$y <- with(dat, 1.5 + sin(x) + rnorm(n, sd = 0.6))

## write data to dir
write.table(dat, file.path(dir, "data.raw"),
  quote = FALSE, row.names = FALSE)

## create the .prg file
writeLines("bayesreg b
dataset d 
d.infile using data.raw
b.outfile = mcmc
b.regress y = x(psplinerw2,nrknots=20,degree=3), family=gaussian predict using d
b.getsample", prg)

## run the .prg file from R
run.bayesx(prg)

Run the code above in your browser using DataLab